@@ -3,16 +3,14 @@ extern crate libc;
 use std::os::raw::{c_char, c_double, c_float, c_int, c_longlong};
 
 #[repr(C)]
-pub struct MfNode
-{
+pub struct MfNode {
     pub u: c_int,
     pub v: c_int,
     pub r: c_float
 }
 
 #[repr(C)]
-pub struct MfProblem
-{
+pub struct MfProblem {
     pub m: c_int,
     pub n: c_int,
     pub nnz: c_longlong,
@@ -20,8 +18,9 @@ pub struct MfProblem
 }
 
 #[repr(C)]
+#[derive(Clone, Copy)]
 pub struct MfParameter {
-    pub fun: c_int,
+    pub fun: Loss,
     pub k: c_int,
     pub nr_threads: c_int,
     pub nr_bins: c_int,
@@ -39,9 +38,8 @@ pub struct MfParameter {
 }
 
 #[repr(C)]
-pub struct MfModel
-{
-    pub fun: c_int,
+pub struct MfModel {
+    pub fun: Loss,
     pub m: c_int,
     pub n: c_int,
     pub k: c_int,
@@ -50,6 +48,20 @@ pub struct MfModel
     pub q: *const c_float
 }
 
+#[repr(C)]
+#[derive(Clone, Copy)]
+pub enum Loss {
+    RealL2 = 0,
+    RealL1 = 1,
+    RealKL = 2,
+    BinaryLog = 5,
+    BinaryL2 = 6,
+    BinaryL1 = 7,
+    OneClassRow = 10,
+    OneClassCol = 11,
+    OneClassL2 = 12
+}
+
 extern "C" {
     pub fn mf_get_default_param() -> MfParameter;
     pub fn mf_save_model(model: *const MfModel, path: *const c_char) -> c_int;
